.. _user-docs:

**********
User Guide
**********

.. toctree::
   :caption: Data structures and transformations
   :maxdepth: 1

   constants/index
   units/index
   nddata/index
   table/index
   time/index
   timeseries/index
   coordinates/index
   wcs/index
   modeling/index
   uncertainty/index

.. toctree::
   :caption: Files, I/O, and Communication
   :maxdepth: 1

   io/unified
   io/fits/index
   io/ascii/index
   io/votable/index
   io/misc
   io/typing
   samp/index

.. toctree::
   :caption: Computations and utilities
   :maxdepth: 1

   cosmology/index
   convolution/index
   utils/iers
   visualization/index
   stats/index

.. toctree::
   :caption: Nuts and bolts
   :maxdepth: 1

   config/index
   io/registry
   logging
   warnings
   utils/index
   glossary
